# TAC Controller

This is a controller agent for a Trading Agent Competition (TAC).

## Description

This agent is part of the Fetch.ai TAC demo. 

It uses its `fetchai/tac_control` skill to manage the progression of a competition across various stages.

## Links

* <a href="https://docs.fetch.ai/aea/tac-skills-contract/" target="_blank">TAC Demo</a>
